---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

* **What is the current behaviour?**


* **What is the new behaviour you are suggesting?**


* **What is the motivation / use case for changing the behaviour? Does this let PySketcher be used for something which it can't be used for at the moment?**
